@@ -35,7 +35,7 @@ class Adapter(object):
         for longname, (shortname, conv) in self._parameters.items():
             try:
                 final[shortname] = conv(row.pop(longname, None))
-            except ValueError:
+            except (ValueError, TypeError):
                 final[shortname] = None
 
         for k in row:
